@@ -4,9 +4,9 @@ use ckb_chain_spec::consensus::{Consensus, ConsensusBuilder};
 use ckb_dao::DaoCalculator;
 use ckb_dao_utils::genesis_dao_data;
 use ckb_jsonrpc_types::ScriptHashType;
+use ckb_launcher::SharedBuilder;
 use ckb_network::{DefaultExitHandler, NetworkController, NetworkService, NetworkState};
 use ckb_shared::shared::Shared;
-use ckb_shared::SharedBuilder;
 use ckb_store::ChainStore;
 pub use ckb_test_chain_utils::MockStore;
 use ckb_test_chain_utils::{
@@ -24,7 +24,7 @@ use ckb_types::{
     h256,
     packed::{self, Byte32, CellDep, CellInput, CellOutput, CellOutputBuilder, OutPoint},
     utilities::{difficulty_to_compact, DIFF_TWO},
-    H256, U256,
+    U256,
 };
 use std::collections::HashSet;
 use std::sync::Arc;
@@ -117,6 +117,8 @@ pub(crate) fn start_chain(consensus: Option<Consensus>) -> (ChainController, Sha
         args: Default::default(),
         hash_type: ScriptHashType::Data,
         message: Default::default(),
+        use_binary_version_as_message_prefix: false,
+        binary_version: "TEST".to_string(),
     };
 
     let (shared, mut pack) = builder
@@ -284,7 +286,7 @@ pub(crate) fn dummy_network(shared: &Shared) -> NetworkController {
         connect_outbound_interval_secs: 1,
         discovery_local_address: true,
         bootnode_mode: true,
-        reuse: true,
+        reuse_port_on_linux: true,
         ..Default::default()
     };
 
